Site Manager Goals
==================

  * Provide an online collaboration environment for an organization
    or community.

    - "Create a CMF site":CreateCMFSite

    - "Configure CMF site":ConfigureCMFSite

  * Maintain an overall site structure and organization.

    - "Create CMF Folder":CreateCMFFolder

    - "Create CMF Topic":CreateCMFTopic

    - **XXX** "Configure CMF Topic":ConfigureCMFTopic

    - **XXX** "Configure what types of content can be created by
       members":ConfigureAllowedContentTypes

  * Implement security policies for the site.

    - **XXX** "Configure security for a content object
       or folder":ConfigureObjectSecurity

  * Implement workflow policies for the site.

    - **XXX** "Associate a workflow with a content
       type":AssociateWorkflowWithContentType

  * Implement metadata policies for the site.

    - **XXX** "Configure required metadata for a content
       type":ConfigureRequiredMetadata

  * Implement syndication policies for the site.

    - **XXX** "Configure what content is released via
       syndication":ConfigureContentSyndication

